@@ -14,8 +14,7 @@ import sys
 import time
 import urllib
 import warnings
-from codecs import StreamWriter, getwriter
-from collections.abc import MutableMapping, MutableSequence
+from codecs import getwriter
 from typing import (
     IO,
     Any,
@@ -27,7 +26,6 @@ from typing import (
     MutableSequence,
     Optional,
     Sized,
-    TextIO,
     Tuple,
     Union,
     cast,
@@ -39,7 +37,13 @@ import pkg_resources  # part of setuptools
 from schema_salad.exceptions import ValidationException
 from schema_salad.ref_resolver import Loader, file_uri, uri_file_path
 from schema_salad.sourceline import cmap, strip_dup_lineno
-from schema_salad.utils import ContextType, FetcherCallableType, json_dumps, yaml_no_ts
+from schema_salad.utils import (
+    ContextType,
+    FetcherCallableType,
+    json_dump,
+    json_dumps,
+    yaml_no_ts,
+)
 
 import ruamel.yaml
 from ruamel.yaml.comments import CommentedMap, CommentedSeq
@@ -179,9 +183,7 @@ def generate_example_input(
         "float": 0.1,
         "double": 0.1,
         "string": "a_string",
-        "File": ruamel.yaml.comments.CommentedMap(
-            [("class", "File"), ("path", "a/file/path")]
-        ),
+        "File": ruamel.yaml.comments.CommentedMap([("class", "File"), ("path", "a/file/path")]),
         "Directory": ruamel.yaml.comments.CommentedMap(
             [("class", "Directory"), ("path", "a/directory/path")]
         ),
@@ -248,17 +250,17 @@ def generate_example_input(
                 example.insert(0, shortname(cast(str, field["name"])), value, f_comment)
         elif "default" in inptype:
             example = inptype["default"]
-            comment = 'default value of type "{}".'.format(inptype["type"])
+            comment = f"default value of type {inptype['type']!r}"
         else:
             example = defaults.get(cast(str, inptype["type"]), str(inptype))
-            comment = 'type "{}".'.format(inptype["type"])
+            comment = f"type {inptype['type']!r}"
     else:
         if not default:
             example = defaults.get(str(inptype), str(inptype))
-            comment = f'type "{inptype}"'
+            comment = f"type {inptype!r}"
         else:
             example = default
-            comment = f'default value of type "{inptype}".'
+            comment = f"default value of type {inptype!r}."
     return example, comment
 
 
@@ -300,16 +302,10 @@ def realize_input_schema(
             if isinstance(entry["type"], Mapping):
                 entry["type"] = cast(
                     CWLOutputAtomType,
-                    realize_input_schema(
-                        [cast(CWLObjectType, entry["type"])], schema_defs
-                    ),
+                    realize_input_schema([cast(CWLObjectType, entry["type"])], schema_defs),
                 )
             if entry["type"] == "array":
-                items = (
-                    entry["items"]
-                    if not isinstance(entry["items"], str)
-                    else [entry["items"]]
-                )
+                items = entry["items"] if not isinstance(entry["items"], str) else [entry["items"]]
                 entry["items"] = cast(
                     CWLOutputAtomType,
                     realize_input_schema(
@@ -321,9 +317,7 @@ def realize_input_schema(
                 entry["fields"] = cast(
                     CWLOutputAtomType,
                     realize_input_schema(
-                        cast(
-                            MutableSequence[Union[str, CWLObjectType]], entry["fields"]
-                        ),
+                        cast(MutableSequence[Union[str, CWLObjectType]], entry["fields"]),
                         schema_defs,
                     ),
                 )
@@ -350,7 +344,6 @@ def load_job_order(
     overrides_list: List[CWLObjectType],
     tool_file_uri: str,
 ) -> Tuple[Optional[CWLObjectType], str, Loader]:
-
     job_order_object = None
     job_order_file = None
 
@@ -362,9 +355,7 @@ def load_job_order(
     elif len(args.job_order) == 1 and args.job_order[0] == "-":
         yaml = yaml_no_ts()
         job_order_object = yaml.load(stdin)
-        job_order_object, _ = loader.resolve_all(
-            job_order_object, file_uri(os.getcwd()) + "/"
-        )
+        job_order_object, _ = loader.resolve_all(job_order_object, file_uri(os.getcwd()) + "/")
     else:
         job_order_file = None
 
@@ -372,9 +363,7 @@ def load_job_order(
         input_basedir = args.basedir if args.basedir else os.getcwd()
     elif job_order_file is not None:
         input_basedir = (
-            args.basedir
-            if args.basedir
-            else os.path.abspath(os.path.dirname(job_order_file))
+            args.basedir if args.basedir else os.path.abspath(os.path.dirname(job_order_file))
         )
         job_order_object, _ = loader.resolve_ref(
             job_order_file,
@@ -382,22 +371,15 @@ def load_job_order(
             content_types=CWL_CONTENT_TYPES,
         )
 
-    if (
-        job_order_object is not None
-        and "http://commonwl.org/cwltool#overrides" in job_order_object
-    ):
+    if job_order_object is not None and "http://commonwl.org/cwltool#overrides" in job_order_object:
         ov_uri = file_uri(job_order_file or input_basedir)
-        overrides_list.extend(
-            resolve_overrides(job_order_object, ov_uri, tool_file_uri)
-        )
+        overrides_list.extend(resolve_overrides(job_order_object, ov_uri, tool_file_uri))
         del job_order_object["http://commonwl.org/cwltool#overrides"]
 
     if job_order_object is None:
         input_basedir = args.basedir if args.basedir else os.getcwd()
 
-    if job_order_object is not None and not isinstance(
-        job_order_object, MutableMapping
-    ):
+    if job_order_object is not None and not isinstance(job_order_object, MutableMapping):
         _logger.error(
             "CWL input object at %s is not formatted correctly, it should be a "
             "JSON/YAML dictionary, not %s.\n"
@@ -415,7 +397,7 @@ def init_job_order(
     args: argparse.Namespace,
     process: Process,
     loader: Loader,
-    stdout: Union[TextIO, StreamWriter],
+    stdout: IO[str],
     print_input_deps: bool = False,
     relative_deps: str = "primary",
     make_fs_access: Callable[[str], StdFsAccess] = StdFsAccess,
@@ -438,14 +420,12 @@ def init_job_order(
             file_uri(os.getcwd()) + "/",
         )
         if args.tool_help:
-            toolparser.print_help(cast(IO[str], stdout))
+            toolparser.print_help(stdout)
             exit(0)
         cmd_line = vars(toolparser.parse_args(args.job_order))
         for record_name in records:
             record = {}
-            record_items = {
-                k: v for k, v in cmd_line.items() if k.startswith(record_name)
-            }
+            record_items = {k: v for k, v in cmd_line.items() if k.startswith(record_name)}
             for key, value in record_items.items():
                 record[key[len(record_name) + 1 :]] = value
                 del cmd_line[key]
@@ -457,9 +437,7 @@ def init_job_order(
                     loader.resolve_ref(cmd_line["job_order"])[0],
                 )
             except Exception:
-                _logger.exception(
-                    "Failed to resolv job_order: %s", cmd_line["job_order"]
-                )
+                _logger.exception("Failed to resolv job_order: %s", cmd_line["job_order"])
                 exit(1)
         else:
             job_order_object = {"id": args.workflow}
@@ -564,7 +542,7 @@ def make_relative(base: str, obj: CWLObjectType) -> None:
 def printdeps(
     obj: CWLObjectType,
     document_loader: Loader,
-    stdout: Union[TextIO, StreamWriter],
+    stdout: IO[str],
     relative_deps: str,
     uri: str,
     basedir: Optional[str] = None,
@@ -577,7 +555,7 @@ def printdeps(
     elif relative_deps == "cwd":
         base = os.getcwd()
     visit_class(deps, ("File", "Directory"), functools.partial(make_relative, base))
-    print(json_dumps(deps, indent=4, default=str), file=stdout)
+    json_dump(deps, stdout, indent=4, default=str)
 
 
 def prov_deps(
@@ -627,9 +605,7 @@ def find_deps(
         nestdirs=nestdirs,
     )
     if sfs is not None:
-        deps["secondaryFiles"] = cast(
-            MutableSequence[CWLOutputAtomType], mergedirs(sfs)
-        )
+        deps["secondaryFiles"] = cast(MutableSequence[CWLOutputAtomType], mergedirs(sfs))
 
     return deps
 
@@ -641,10 +617,10 @@ def print_pack(
     """Return a CWL serialization of the CWL document in JSON."""
     packed = pack(loadingContext, uri)
     if len(cast(Sized, packed["$graph"])) > 1:
-        return json_dumps(packed, indent=4, default=str)
-    return json_dumps(
-        cast(MutableSequence[CWLObjectType], packed["$graph"])[0], indent=4, default=str
-    )
+        target = packed
+    else:
+        target = cast(MutableSequence[CWLObjectType], packed["$graph"])[0]
+    return json_dumps(target, indent=4, default=str)
 
 
 def supported_cwl_versions(enable_dev: bool) -> List[str]:
@@ -691,12 +667,9 @@ class ProvLogFormatter(logging.Formatter):
         """Use the default formatter with our custom formatstring."""
         super().__init__("[%(asctime)sZ] %(message)s")
 
-    def formatTime(
-        self, record: logging.LogRecord, datefmt: Optional[str] = None
-    ) -> str:
-        formatted_time = time.strftime(
-            "%Y-%m-%dT%H:%M:%S", time.gmtime(float(record.created))
-        )
+    def formatTime(self, record: logging.LogRecord, datefmt: Optional[str] = None) -> str:
+        """Override the default formatTime to include the timezone."""
+        formatted_time = time.strftime("%Y-%m-%dT%H:%M:%S", time.gmtime(float(record.created)))
         with_msecs = f"{formatted_time},{record.msecs:03f}"
         return with_msecs
 
@@ -750,9 +723,7 @@ def setup_loadingContext(
         doc_cache=args.doc_cache,
     )
     loadingContext.research_obj = runtimeContext.research_obj
-    loadingContext.disable_js_validation = args.disable_js_validation or (
-        not args.do_validate
-    )
+    loadingContext.disable_js_validation = args.disable_js_validation or (not args.do_validate)
     loadingContext.construct_tool_object = getdefault(
         loadingContext.construct_tool_object, workflow.default_make_tool
     )
@@ -763,27 +734,21 @@ def setup_loadingContext(
     return loadingContext
 
 
-def make_template(
-    tool: Process,
-) -> None:
+def make_template(tool: Process, target: IO[str]) -> None:
     """Make a template CWL input object for the give Process."""
 
-    def my_represent_none(
-        self: Any, data: Any
-    ) -> Any:  # pylint: disable=unused-argument
+    def my_represent_none(self: Any, data: Any) -> Any:  # pylint: disable=unused-argument
         """Force clean representation of 'null'."""
         return self.represent_scalar("tag:yaml.org,2002:null", "null")
 
-    ruamel.yaml.representer.RoundTripRepresenter.add_representer(
-        type(None), my_represent_none
-    )
+    ruamel.yaml.representer.RoundTripRepresenter.add_representer(type(None), my_represent_none)
     yaml = YAML()
     yaml.default_flow_style = False
     yaml.indent = 4
     yaml.block_seq_indent = 2
     yaml.dump(
         generate_input_template(tool),
-        sys.stdout,
+        target,
     )
 
 
@@ -925,8 +890,7 @@ def check_working_directories(
         ):
             sl = (
                 "/"
-                if getattr(runtimeContext, dirprefix).endswith("/")
-                or dirprefix == "cachedir"
+                if getattr(runtimeContext, dirprefix).endswith("/") or dirprefix == "cachedir"
                 else ""
             )
             setattr(
@@ -945,7 +909,7 @@ def check_working_directories(
 
 def print_targets(
     tool: Process,
-    stdout: Union[TextIO, StreamWriter],
+    stdout: IO[str],
     loading_context: LoadingContext,
     prefix: str = "",
 ) -> None:
@@ -954,8 +918,7 @@ def print_targets(
         if tool.tool[f]:
             _logger.info("%s %s%s targets:", prefix[:-1], f[0].upper(), f[1:-1])
             print(
-                "  "
-                + "\n  ".join([f"{prefix}{shortname(t['id'])}" for t in tool.tool[f]]),
+                "  " + "\n  ".join([f"{prefix}{shortname(t['id'])}" for t in tool.tool[f]]),
                 file=stdout,
             )
     if "steps" in tool.tool:
@@ -972,9 +935,7 @@ def print_targets(
                 process = make_tool(cast(CommentedMap, cmap(run)), loading_context)
             else:
                 process = run
-            print_targets(
-                process, stdout, loading_context, f"{prefix}{shortname(t['id'])}/"
-            )
+            print_targets(process, stdout, loading_context, f"{prefix}{shortname(t['id'])}/")
 
 
 def main(
@@ -982,7 +943,7 @@ def main(
     args: Optional[argparse.Namespace] = None,
     job_order_object: Optional[CWLObjectType] = None,
     stdin: IO[Any] = sys.stdin,
-    stdout: Optional[Union[TextIO, StreamWriter]] = None,
+    stdout: Optional[IO[str]] = None,
     stderr: IO[Any] = sys.stderr,
     versionfunc: Callable[[], str] = versionstring,
     logger_handler: Optional[logging.Handler] = None,
@@ -992,7 +953,7 @@ def main(
     runtimeContext: Optional[RuntimeContext] = None,
     input_required: bool = True,
 ) -> int:
-    if not stdout:  # force UTF-8 even if the console is configured differently
+    if stdout is None:  # force UTF-8 even if the console is configured differently
         if hasattr(sys.stdout, "encoding") and sys.stdout.encoding.upper() not in (
             "UTF-8",
             "UTF8",
@@ -1000,9 +961,10 @@ def main(
             if hasattr(sys.stdout, "detach"):
                 stdout = io.TextIOWrapper(sys.stdout.buffer, encoding="utf-8")
             else:
-                stdout = getwriter("utf-8")(sys.stdout)  # type: ignore
+                stdout = getwriter("utf-8")(sys.stdout)  # type: ignore[assignment,arg-type]
         else:
             stdout = sys.stdout
+        stdout = cast(IO[str], stdout)
 
     _logger.removeHandler(defaultStreamHandler)
     stderr_handler = logger_handler
@@ -1086,9 +1048,7 @@ def main(
             if argsl is None:
                 raise Exception("argsl cannot be None")
             try:
-                prov_log_stream, prov_log_handler = setup_provenance(
-                    args, argsl, runtimeContext
-                )
+                prov_log_stream, prov_log_handler = setup_provenance(args, argsl, runtimeContext)
             except ArgumentException:
                 return 1
 
@@ -1100,9 +1060,7 @@ def main(
             fetcher_constructor=loadingContext.fetcher_constructor,
         )
 
-        try_again_msg = (
-            "" if args.debug else ", try again with --debug for more information"
-        )
+        try_again_msg = "" if args.debug else ", try again with --debug for more information"
 
         try:
             job_order_object, input_basedir, jobloader = load_job_order(
@@ -1115,17 +1073,13 @@ def main(
 
             if args.overrides:
                 loadingContext.overrides_list.extend(
-                    load_overrides(
-                        file_uri(os.path.abspath(args.overrides)), tool_file_uri
-                    )
+                    load_overrides(file_uri(os.path.abspath(args.overrides)), tool_file_uri)
                 )
 
             loadingContext, workflowobj, uri = fetch_document(uri, loadingContext)
 
             if args.print_deps and loadingContext.loader:
-                printdeps(
-                    workflowobj, loadingContext.loader, stdout, args.relative_deps, uri
-                )
+                printdeps(workflowobj, loadingContext.loader, stdout, args.relative_deps, uri)
                 return 0
 
             loadingContext, uri = resolve_and_validate_document(
@@ -1133,7 +1087,6 @@ def main(
                 workflowobj,
                 uri,
                 preprocess_only=(args.print_pre or args.pack),
-                skip_schemas=args.skip_schemas,
             )
 
             if loadingContext.loader is None:
@@ -1146,20 +1099,16 @@ def main(
 
             if args.provenance and runtimeContext.research_obj:
                 # Can't really be combined with args.pack at same time
-                runtimeContext.research_obj.packed_workflow(
-                    print_pack(loadingContext, uri)
-                )
+                runtimeContext.research_obj.packed_workflow(print_pack(loadingContext, uri))
 
             if args.print_pre:
-                print(
-                    json_dumps(
-                        processobj,
-                        indent=4,
-                        sort_keys=True,
-                        separators=(",", ": "),
-                        default=str,
-                    ),
-                    file=stdout,
+                json_dump(
+                    processobj,
+                    stdout,
+                    indent=4,
+                    sort_keys=True,
+                    separators=(",", ": "),
+                    default=str,
                 )
                 return 0
 
@@ -1179,7 +1128,7 @@ def main(
                     raise main_missing_exc
 
             if args.make_template:
-                make_template(tool)
+                make_template(tool, stdout)
                 return 0
 
             if args.validate:
@@ -1225,22 +1174,18 @@ def main(
             if args.print_subgraph:
                 if "name" in tool.tool:
                     del tool.tool["name"]
-                print(
-                    json_dumps(
-                        tool.tool,
-                        indent=4,
-                        sort_keys=True,
-                        separators=(",", ": "),
-                        default=str,
-                    ),
-                    file=stdout,
+                json_dump(
+                    tool.tool,
+                    stdout,
+                    indent=4,
+                    sort_keys=True,
+                    separators=(",", ": "),
+                    default=str,
                 )
                 return 0
 
-        except (ValidationException) as exc:
-            _logger.error(
-                "Tool definition failed validation:\n%s", str(exc), exc_info=args.debug
-            )
+        except ValidationException as exc:
+            _logger.error("Tool definition failed validation:\n%s", str(exc), exc_info=args.debug)
             return 1
         except (RuntimeError, WorkflowException) as exc:
             _logger.error(
@@ -1281,12 +1226,8 @@ def main(
 
         runtimeContext.log_dir = args.log_dir
 
-        runtimeContext.secret_store = getdefault(
-            runtimeContext.secret_store, SecretStore()
-        )
-        runtimeContext.make_fs_access = getdefault(
-            runtimeContext.make_fs_access, StdFsAccess
-        )
+        runtimeContext.secret_store = getdefault(runtimeContext.secret_store, SecretStore())
+        runtimeContext.make_fs_access = getdefault(runtimeContext.make_fs_access, StdFsAccess)
 
         if not executor:
             if args.parallel:
@@ -1307,13 +1248,9 @@ def main(
                     tfjob_order.update(loadingContext.jobdefaults)
                 if job_order_object:
                     tfjob_order.update(job_order_object)
-                tfout, tfstatus = real_executor(
-                    tool.embedded_tool, tfjob_order, runtimeContext
-                )
+                tfout, tfstatus = real_executor(tool.embedded_tool, tfjob_order, runtimeContext)
                 if not tfout or tfstatus != "success":
-                    raise WorkflowException(
-                        "ProcessGenerator failed to generate workflow"
-                    )
+                    raise WorkflowException("ProcessGenerator failed to generate workflow")
                 tool, job_order_object = tool.result(tfjob_order, tfout, runtimeContext)
                 if not job_order_object:
                     job_order_object = None
@@ -1342,12 +1279,8 @@ def main(
             del args.workflow
             del args.job_order
 
-            conf_file = getattr(
-                args, "beta_dependency_resolvers_configuration", None
-            )  # str
-            use_conda_dependencies = getattr(
-                args, "beta_conda_dependencies", None
-            )  # str
+            conf_file = getattr(args, "beta_dependency_resolvers_configuration", None)  # str
+            use_conda_dependencies = getattr(args, "beta_conda_dependencies", None)  # str
 
             if conf_file or use_conda_dependencies:
                 runtimeContext.job_script_provider = DependenciesConfiguration(args)
@@ -1398,12 +1331,13 @@ def main(
                 # Unsetting the Generation from final output object
                 visit_class(out, ("File",), MutationManager().unset_generation)
 
-                print(
-                    json_dumps(out, indent=4, ensure_ascii=False, default=str),
-                    file=stdout,
-                )
-                if hasattr(stdout, "flush"):
-                    stdout.flush()
+                if args.write_summary:
+                    with open(args.write_summary, "w") as output_file:
+                        json_dump(out, output_file, indent=4, ensure_ascii=False, default=str)
+                else:
+                    json_dump(out, stdout, indent=4, ensure_ascii=False, default=str)
+                    if hasattr(stdout, "flush"):
+                        stdout.flush()
 
             if status != "success":
                 _logger.warning("Final process status is %s", status)
@@ -1411,10 +1345,8 @@ def main(
             _logger.info("Final process status is %s", status)
             return 0
 
-        except (ValidationException) as exc:
-            _logger.error(
-                "Input object failed validation:\n%s", str(exc), exc_info=args.debug
-            )
+        except ValidationException as exc:
+            _logger.error("Input object failed validation:\n%s", str(exc), exc_info=args.debug)
             return 1
         except UnsupportedRequirement as exc:
             _logger.error(
@@ -1450,9 +1382,7 @@ def main(
         ):
             research_obj = runtimeContext.research_obj
             if loadingContext.loader is not None:
-                research_obj.generate_snapshot(
-                    prov_deps(workflowobj, loadingContext.loader, uri)
-                )
+                research_obj.generate_snapshot(prov_deps(workflowobj, loadingContext.loader, uri))
             else:
                 _logger.warning(
                     "Unable to generate provenance snapshot "
@@ -1460,9 +1390,7 @@ def main(
                 )
             if prov_log_handler is not None:
                 # Stop logging so we won't half-log adding ourself to RO
-                _logger.debug(
-                    "[provenance] Closing provenance log file %s", prov_log_handler
-                )
+                _logger.debug("[provenance] Closing provenance log file %s", prov_log_handler)
                 _logger.removeHandler(prov_log_handler)
                 # Ensure last log lines are written out
                 prov_log_handler.flush()
@@ -1485,9 +1413,7 @@ def find_default_container(
 ) -> Optional[str]:
     """Find a container."""
     if not default_container and use_biocontainers:
-        default_container = get_container_from_software_requirements(
-            use_biocontainers, builder
-        )
+        default_container = get_container_from_software_requirements(use_biocontainers, builder)
     return default_container
 
 
@@ -1507,15 +1433,17 @@ def windows_check() -> None:
         )
 
 
-def run(*args: Any, **kwargs: Any) -> None:
+def run(*args: Any, **kwargs: Any) -> int:
     """Run cwltool."""
     windows_check()
     signal.signal(signal.SIGTERM, _signal_handler)
+    retval = 1
     try:
-        sys.exit(main(*args, **kwargs))
+        retval = main(*args, **kwargs)
     finally:
         _terminate_processes()
+    return retval
 
 
 if __name__ == "__main__":
-    run(sys.argv[1:])
+    sys.exit(run(sys.argv[1:]))
