@@ -195,9 +195,7 @@ param_to_expr_interpolate_escapebehavior = (
 )
 
 
-@pytest.mark.parametrize(
-    "pattern,expected,behavior", param_to_expr_interpolate_escapebehavior
-)
+@pytest.mark.parametrize("pattern,expected,behavior", param_to_expr_interpolate_escapebehavior)
 def test_parameter_to_expression_interpolate_escapebehavior(
     pattern: str, expected: str, behavior: int
 ) -> None:
@@ -250,9 +248,8 @@ interpolate_bad_parameters = [
 
 @pytest.mark.parametrize("pattern", interpolate_bad_parameters)
 def test_expression_interpolate_failures(pattern: str) -> None:
-    result = None
     with pytest.raises(JavascriptException):
-        result = expr.interpolate(pattern, interpolate_input)
+        expr.interpolate(pattern, interpolate_input)
 
 
 interpolate_escapebehavior = (
@@ -280,14 +277,9 @@ interpolate_escapebehavior = (
 
 
 @pytest.mark.parametrize("pattern,expected,behavior", interpolate_escapebehavior)
-def test_expression_interpolate_escapebehavior(
-    pattern: str, expected: str, behavior: int
-) -> None:
+def test_expression_interpolate_escapebehavior(pattern: str, expected: str, behavior: int) -> None:
     """Test escaping behavior in an interpolation context."""
-    assert (
-        expr.interpolate(pattern, interpolate_input, escaping_behavior=behavior)
-        == expected
-    )
+    assert expr.interpolate(pattern, interpolate_input, escaping_behavior=behavior) == expected
 
 
 def test_factory() -> None:
@@ -331,13 +323,9 @@ def test_factory_partial_scatter() -> None:
 
     result = err_info.value.out
     assert isinstance(result, dict)
-    assert (
-        result["out"][0]["checksum"] == "sha1$e5fa44f2b31c1fb553b6021e7360d07d5d91ff5e"
-    )
+    assert result["out"][0]["checksum"] == "sha1$e5fa44f2b31c1fb553b6021e7360d07d5d91ff5e"
     assert result["out"][1] is None
-    assert (
-        result["out"][2]["checksum"] == "sha1$a3db5c13ff90a36963278c6a39e4ee3c22e2a436"
-    )
+    assert result["out"][2]["checksum"] == "sha1$a3db5c13ff90a36963278c6a39e4ee3c22e2a436"
 
 
 def test_factory_partial_output() -> None:
@@ -614,15 +602,18 @@ record = {
     "fields": [
         {
             "type": {"items": "string", "type": "array"},
-            "name": "file:///home/chapmanb/drive/work/cwl/test_bcbio_cwl/run_info-cwl-workflow/wf-variantcall.cwl#vc_rec/vc_rec/description",
+            "name": "file:///home/chapmanb/drive/work/cwl/test_bcbio_cwl/"
+            "run_info-cwl-workflow/wf-variantcall.cwl#vc_rec/vc_rec/description",
         },
         {
             "type": {"items": "File", "type": "array"},
-            "name": "file:///home/chapmanb/drive/work/cwl/test_bcbio_cwl/run_info-cwl-workflow/wf-variantcall.cwl#vc_rec/vc_rec/vrn_file",
+            "name": "file:///home/chapmanb/drive/work/cwl/test_bcbio_cwl/"
+            "run_info-cwl-workflow/wf-variantcall.cwl#vc_rec/vc_rec/vrn_file",
         },
     ],
     "type": "record",
-    "name": "file:///home/chapmanb/drive/work/cwl/test_bcbio_cwl/run_info-cwl-workflow/wf-variantcall.cwl#vc_rec/vc_rec",
+    "name": "file:///home/chapmanb/drive/work/cwl/test_bcbio_cwl/"
+    "run_info-cwl-workflow/wf-variantcall.cwl#vc_rec/vc_rec",
 }
 
 source_to_sink = [
@@ -810,16 +801,12 @@ typechecks = [
 ]
 
 
-@pytest.mark.parametrize(
-    "src_type,sink_type,link_merge,value_from,expected_type", typechecks
-)
+@pytest.mark.parametrize("src_type,sink_type,link_merge,value_from,expected_type", typechecks)
 def test_typechecking(
     src_type: Any, sink_type: Any, link_merge: str, value_from: Any, expected_type: str
 ) -> None:
     assert (
-        cwltool.checker.check_types(
-            src_type, sink_type, linkMerge=link_merge, valueFrom=value_from
-        )
+        cwltool.checker.check_types(src_type, sink_type, linkMerge=link_merge, valueFrom=value_from)
         == expected_type
     )
 
@@ -869,8 +856,8 @@ def test_format_expr_error() -> None:
     stderr = re.sub(r"\s\s+", " ", stderr)
     assert (
         "An expression in the 'format' field must evaluate to a string, or list "
-        "of strings. However a non-string item was received: '42' of "
-        "type '<class 'int'>'." in stderr
+        "of strings. However a non-string item was received: 42 of "
+        "type <class 'int'>." in stderr
     )
 
 
@@ -1000,9 +987,7 @@ def test_var_spool_cwl_checker3() -> None:
     factory = cwltool.factory.Factory()
     try:
         factory.make(get_data("tests/portable.cwl"))
-        assert (
-            "Non-portable reference to /var/spool/cwl detected" not in stream.getvalue()
-        )
+        assert "Non-portable reference to /var/spool/cwl detected" not in stream.getvalue()
     finally:
         _logger.removeHandler(streamhandler)
 
@@ -1060,12 +1045,8 @@ def test_print_dot() -> None:
     stdout = StringIO()
     assert main(["--debug", "--print-dot", cwl_path], stdout=stdout) == 0
     computed_dot = pydot.graph_from_dot_data(stdout.getvalue())[0]
-    computed_edges = sorted(
-        (source, target) for source, target in computed_dot.obj_dict["edges"]
-    )
-    expected_edges = sorted(
-        (source, target) for source, target in expected_dot.obj_dict["edges"]
-    )
+    computed_edges = sorted((source, target) for source, target in computed_dot.obj_dict["edges"])
+    expected_edges = sorted((source, target) for source, target in expected_dot.obj_dict["edges"])
     assert computed_edges == expected_edges
 
     # print CommandLineTool
@@ -1078,14 +1059,10 @@ test_factors = [(""), ("--parallel"), ("--debug"), ("--parallel --debug")]
 
 
 @pytest.mark.parametrize("factor", test_factors)
-def test_js_console_cmd_line_tool(
-    factor: str, caplog: pytest.LogCaptureFixture
-) -> None:
+def test_js_console_cmd_line_tool(factor: str, caplog: pytest.LogCaptureFixture) -> None:
     for test_file in ("js_output.cwl", "js_output_workflow.cwl"):
         commands = factor.split()
-        commands.extend(
-            ["--js-console", "--no-container", get_data("tests/wf/" + test_file)]
-        )
+        commands.extend(["--js-console", "--no-container", get_data("tests/wf/" + test_file)])
         error_code, _, _ = get_main_output(commands)
         logging_output = "\n".join([record.message for record in caplog.records])
         assert "[log] Log message" in logging_output
@@ -1113,9 +1090,7 @@ def test_cid_file_dir(tmp_path: Path, factor: str) -> None:
     test_file = "cache_test_workflow.cwl"
     with working_directory(tmp_path):
         commands = factor.split()
-        commands.extend(
-            ["--cidfile-dir", str(tmp_path), get_data("tests/wf/" + test_file)]
-        )
+        commands.extend(["--cidfile-dir", str(tmp_path), get_data("tests/wf/" + test_file)])
         error_code, stdout, stderr = get_main_output(commands)
         stderr = re.sub(r"\s\s+", " ", stderr)
         assert "completed success" in stderr
@@ -1133,9 +1108,7 @@ def test_cid_file_dir_arg_is_file_instead_of_dir(tmp_path: Path, factor: str) ->
     bad_cidfile_dir = tmp_path / "cidfile-dir-actually-a-file"
     bad_cidfile_dir.touch()
     commands = factor.split()
-    commands.extend(
-        ["--cidfile-dir", str(bad_cidfile_dir), get_data("tests/wf/" + test_file)]
-    )
+    commands.extend(["--cidfile-dir", str(bad_cidfile_dir), get_data("tests/wf/" + test_file)])
     error_code, _, stderr = get_main_output(commands)
     stderr = re.sub(r"\s\s+", " ", stderr)
     assert "is not a directory, please check it first" in stderr, stderr
@@ -1348,6 +1321,31 @@ def test_cache_relative_paths(tmp_path: Path, factor: str) -> None:
     assert (tmp_path / "cwltool_cache" / "27903451fc1ee10c148a0bdeb845b2cf").exists()
 
 
+def test_write_summary(tmp_path: Path) -> None:
+    """Test --write-summary."""
+    commands = [
+        get_data("tests/wf/no-parameters-echo.cwl"),
+    ]
+    error_code, stdout, stderr = get_main_output(commands)
+    stderr = re.sub(r"\s\s+", " ", stderr)
+    assert error_code == 0, stderr
+
+    final_output_path = str(tmp_path / "final-output.json")
+    commands_no = [
+        "--write-summary",
+        final_output_path,
+        get_data("tests/wf/no-parameters-echo.cwl"),
+    ]
+    error_code, stdout_no, stderr = get_main_output(commands_no)
+    stderr = re.sub(r"\s\s+", " ", stderr)
+    assert error_code == 0, stderr
+
+    with open(final_output_path) as f:
+        final_output_str = f.read()
+
+    assert len(stdout_no) + len(final_output_str) == len(stdout)
+
+
 @needs_docker
 def test_compute_checksum() -> None:
     runtime_context = RuntimeContext()
@@ -1377,7 +1375,7 @@ def test_bad_stdin_expr_error() -> None:
     assert error_code == 1
     stderr = re.sub(r"\s\s+", " ", stderr)
     assert (
-        "'stdin' expression must return a string or null. Got '1111' for '$(inputs.file1.size)'."
+        "'stdin' expression must return a string or null. Got 1111 for '$(inputs.file1.size)'."
         in stderr
     )
 
@@ -1394,8 +1392,7 @@ def test_bad_stderr_expr_error() -> None:
     assert error_code == 1
     stderr = re.sub(r"\s\s+", " ", stderr)
     assert (
-        "'stderr' expression must return a string. Got '1111' for '$(inputs.file1.size)'."
-        in stderr
+        "'stderr' expression must return a string. Got 1111 for '$(inputs.file1.size)'." in stderr
     )
 
 
@@ -1411,8 +1408,7 @@ def test_bad_stdout_expr_error() -> None:
     assert error_code == 1
     stderr = re.sub(r"\s\s+", " ", stderr)
     assert (
-        "'stdout' expression must return a string. Got '1111' for '$(inputs.file1.size)'."
-        in stderr
+        "'stdout' expression must return a string. Got 1111 for '$(inputs.file1.size)'." in stderr
     )
 
 
@@ -1553,7 +1549,8 @@ def test_env_filtering(factor: str) -> None:
   local trueExe nextTarget 2>/dev/null
   trueExe=$(ps -o comm= $$) || return 1
   [ "${trueExe#-}" = "$trueExe" ] || trueExe=${trueExe#-}
-  [ "${trueExe#/}" != "$trueExe" ] || trueExe=$([ -n "$ZSH_VERSION" ] && which -p "$trueExe" || which "$trueExe")
+  [ "${trueExe#/}" != "$trueExe" ] || trueExe=$([ -n "$ZSH_VERSION" ] \
+          && which -p "$trueExe" || which "$trueExe")
   while nextTarget=$(readlink "$trueExe"); do trueExe=$nextTarget; done
   printf '%s\n' "$(basename "$trueExe")"
 } ; getTrueShellExeName""",
@@ -1585,16 +1582,14 @@ def test_env_filtering(factor: str) -> None:
 
 def test_v1_0_arg_empty_prefix_separate_false() -> None:
     test_file = "tests/arg-empty-prefix-separate-false.cwl"
-    error_code, stdout, stderr = get_main_output(
-        ["--debug", get_data(test_file), "--echo"]
-    )
+    error_code, stdout, stderr = get_main_output(["--debug", get_data(test_file), "--echo"])
     stderr = re.sub(r"\s\s+", " ", stderr)
     assert "completed success" in stderr
     assert error_code == 0
 
 
 def test_scatter_output_filenames(tmp_path: Path) -> None:
-    """If a scatter step produces identically named output then confirm that the final output is renamed correctly."""
+    """Confirm that the final output is renamed correctly from identically named scatter outputs."""
     cwd = Path.cwd()
     with working_directory(tmp_path):
         rtc = RuntimeContext()
@@ -1655,10 +1650,7 @@ def test_arguments_self() -> None:
     outputs = cast(Dict[str, Any], check())
     assert "self_review" in outputs
     assert len(outputs) == 1
-    assert (
-        outputs["self_review"]["checksum"]
-        == "sha1$724ba28f4a9a1b472057ff99511ed393a45552e1"
-    )
+    assert outputs["self_review"]["checksum"] == "sha1$724ba28f4a9a1b472057ff99511ed393a45552e1"
 
 
 def test_bad_timelimit_expr() -> None:
@@ -1686,7 +1678,7 @@ def test_bad_networkaccess_expr() -> None:
     stderr = re.sub(r"\s\s+", " ", stderr)
     assert (
         "'networkAccess' expression must evaluate to a bool. "
-        "Got '42' for expression '${return 42;}" in stderr
+        "Got 42 for expression '${return 42;}" in stderr
     )
     assert err_code == 1
 
@@ -1748,9 +1740,7 @@ def test_record_default_with_long() -> None:
     assert result["sixth"]["class"] == "File"
     assert result["sixth"]["basename"] == "whale.txt"
     assert result["sixth"]["size"] == 1111
-    assert (
-        result["sixth"]["checksum"] == "sha1$327fc7aedf4f6b69a42a7c8b808dc5a7aff61376"
-    )
+    assert result["sixth"]["checksum"] == "sha1$327fc7aedf4f6b69a42a7c8b808dc5a7aff61376"
 
 
 def test_record_outputeval(tmp_path: Path) -> None:
@@ -1762,21 +1752,12 @@ def test_record_outputeval(tmp_path: Path) -> None:
     assert "genome_fa" in result
     assert result["genome_fa"]["class"] == "File"
     assert result["genome_fa"]["basename"] == "GRCm38.primary_assembly.genome.fa"
-    assert (
-        result["genome_fa"]["checksum"]
-        == "sha1$da39a3ee5e6b4b0d3255bfef95601890afd80709"
-    )
+    assert result["genome_fa"]["checksum"] == "sha1$da39a3ee5e6b4b0d3255bfef95601890afd80709"
     assert result["genome_fa"]["size"] == 0
     assert "annotation_gtf" in result
     assert result["annotation_gtf"]["class"] == "File"
-    assert (
-        result["annotation_gtf"]["basename"]
-        == "gencode.vM21.primary_assembly.annotation.gtf"
-    )
-    assert (
-        result["annotation_gtf"]["checksum"]
-        == "sha1$da39a3ee5e6b4b0d3255bfef95601890afd80709"
-    )
+    assert result["annotation_gtf"]["basename"] == "gencode.vM21.primary_assembly.annotation.gtf"
+    assert result["annotation_gtf"]["checksum"] == "sha1$da39a3ee5e6b4b0d3255bfef95601890afd80709"
     assert result["annotation_gtf"]["size"] == 0
 
 
