@@ -35,9 +35,7 @@ def test_passthrough_successive(tmp_path: Path) -> None:
         ]
     )
     assert err_code == 0
-    children = sorted(
-        tmp_path.glob("*")
-    )  # This input directory should be left pristine.
+    children = sorted(tmp_path.glob("*"))  # This input directory should be left pristine.
     assert len(children) == 1
     subdir = tmp_path / children[0]
     assert len(sorted(subdir.glob("*"))) == 1
@@ -72,7 +70,7 @@ def test_bad_listing_expression(tmp_path: Path) -> None:
     assert (
         "Expression in a 'InitialWorkdirRequirement.listing' field must return "
         "a list containing zero or more of: File or Directory objects; Dirent "
-        "objects. Got '42' among the results" in stderr
+        "objects. Got 42 among the results" in stderr
     )
     assert err_code == 1
 
