@@ -186,10 +186,10 @@ def test_directory_workflow(tmp_path: Path) -> None:
 
     # Input files should be captured by hash value,
     # even if they were inside a class: Directory
-    for (l, l_hash) in sha1.items():
+    for letter, l_hash in sha1.items():
         prefix = l_hash[:2]  # first 2 letters
         p = folder / "data" / prefix / l_hash
-        assert p.is_file(), f"Could not find {l} as {p}"
+        assert p.is_file(), f"Could not find {letter} as {p}"
 
 
 @needs_docker
@@ -383,9 +383,7 @@ def check_ro(base_path: Path, nested: bool = False) -> None:
 
     packed = urllib.parse.urljoin(arcp_root, "/workflow/packed.cwl")
     primary_job = urllib.parse.urljoin(arcp_root, "/workflow/primary-job.json")
-    primary_prov_nt = urllib.parse.urljoin(
-        arcp_root, "/metadata/provenance/primary.cwlprov.nt"
-    )
+    primary_prov_nt = urllib.parse.urljoin(arcp_root, "/metadata/provenance/primary.cwlprov.nt")
     uuid = arcp.parse_arcp(arcp_root).uuid
 
     highlights = set(g.subjects(OA.motivatedBy, OA.highlighting))
